{% extends "colorbox/popup_form_base.html" %}

{% load url from future %}

{% load i18n %}
{% block title %}{{ title }}{% endblock %}
{% block form_url %}{% url 'coop_cms_set_homepage' article.id %}{% endblock %}
