{% load i18n pagination_tags %}
<div class="library-items library-docs">
  {% autopaginate documents 20 %}  
  {% for doc in documents %}
  <a class="djaloha-document{% if doc.is_private %} private-doc{% endif %}" rel="http://{{current_site.domain}}{{doc.get_download_url}}" title="{{doc.name}}">
        <img src="{{ doc.get_block_url }}" class="cms_doc_bloc" rel="http://{{current_site.domain}}{{doc.get_fileicon_url}}"/>
        <span class="cms_doc_title">{{doc.name}}</span>
  </a>
  {% endfor %}
  {% paginate %}  
</div>
