{% load i18n static coop_navigation coop_bar_tags %}<!DOCYTPE html>
<head>
    <title>{% block meta_title %}{% endblock %}{% if site_title %} | {{ site_title }}{% endif %}</title>
    {% block jquery_declaration %}
    <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.7.1.min.js"></script>
    {% endblock %}

    <link rel="stylesheet" href="{{ STATIC_URL }}css/coop_cms.css" type="text/css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}css/demo-style.css" type="text/css" />
    {% coop_bar_headers %}
    {% block extra_head %}{% endblock %}
</head>
<body>
{% coop_bar %}
<div id="container">
<div class="header">
    <h1><a href="/" title="{% trans "Homepage" %}">coop_cms démo</a></h1>
</div>
<div id="main">
  {% block navigation %}
  <ul id="nav">
    {% navigation_as_nested_ul li_template="dropdown_li.html" ul_template="dropdown_ul.html" li_args="dropdown_li_class.html" %}
  </ul>
  {% endblock %}
  <div class="document">
      {% block document %}
        {% block title %}{% endblock %}
        {% block content %}{% endblock %}
      {% endblock %}
  </div>
</div>
</div>

{% coop_bar_footer %}
</body>
</html>

