{% extends "colorbox/popup_form_base.html" %}

{% load url from future %}

{% load i18n %}
{% block title %}{% trans "New article" %}{% endblock %}
{% block form_url %}{% url 'coop_cms_new_article' %}{% endblock %}
