{% extends "coop_cms/base.html" %}
{% load i18n djaloha_utils coop_edition %}


{% block meta_title %}{% article_title %}{% endblock %}


{% block jquery_declaration %}
<script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.7.2.min.js"></script>
{# You can add any additional JS libs here #}
{% if_cms_edition %}{% cms_form_media %}{% endif %}
{% endblock %}


{% block document %}
    {% block article %}
        {% include "coop_cms/_article_form.html" %}
        {% if_cms_edition %}
            {% include "coop_cms/_article_publication.html" %}
        {% endif %}
    {% endblock %}
{% endblock %}

