{% load i18n pagination_tags %}
{% spaceless %}
  <div class="library-items library-images">
  {% autopaginate images 15 %}  
  {% for img in images %}
      <img class="djaloha-thumbnail" src="{{ img.as_thumbnail.url }}" title="{{img.name}}" rel="http://{{current_site.domain}}{{img.get_absolute_url}}">
  {% endfor %}
  {% paginate %}  
  </div>
{% endspaceless %}
