{% extends "coop_cms/base.html" %}
{% load i18n static coop_navigation %}

{% block meta_title %}
    {% trans "Site Map" %}
{% endblock %}



{% block extra_head %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" media="screen, print" href="{{ STATIC_URL }}slickmap/slickmap.css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}css/demo-style.css" type="text/css" />
    <style>
      #primaryNav li{
        list-style: none;
      }
      div#main {
        border: none;
        padding: 0 0;
        background: transparent;
      }
    </style>
{% endblock %}

{% block navigation %}
    <ul id="primaryNav" class="col4">{% navigation_as_nested_ul %}</ul>
{% endblock %}

{% block content %}
{% endblock %}