

ul.messages {
	list-style: none;
	border: #ccc solid 3px;
	width: 900px;
	position: absolute;
	top: 5px;
	background: #fff;
}

ul.messages li {
	font-weight: bolder;
}

ul.messages li.success {
	color: #af5;
}

ul.messages li.error {
	color: #f55;
}

.aloha-align-left {
	text-align: left;
}

.aloha-align-right {
	text-align: right;
}

.aloha-align-center {
	text-align: center;
}

.aloha-align-justifiy {
	text-align: justify;
}

img.aloha-align-left {
	float: left;
}

img.aloha-align-right {
	float: right;
}
